==> pegasus-merchandise-api-2.9.5-sources.jar: com/thebeastshop/pegasus/merchandise/cond/PsMatchCampaignCond.java <==
package com.thebeastshop.pegasus.merchandise.cond;

import com.thebeastshop.common.BaseQueryCond;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * @author gongjun
 * @since 2016-07-18
 */
public class PsMatchCampaignCond extends BaseQueryCond {

    protected Boolean matchGlobalCampaigns = true;

    protected Boolean matchCampaign = true;

    private List<Long> campaignIds;

    private List<String> campaignCodes;

    List<Integer> discountTypeIds;

    List<Integer> productScopeIds;

    List<Integer> states;

    private Integer memberLevel;

    private Integer accessWay;

    private BigDecimal discount;

    private BigDecimal bdDiscount;

    private Date startTime;
    private Date endTime;
    private List<Integer> accessWayIds;
    private List<Integer> buIds;

    /**
     * 查询渠道编码，判断活动排除线下门店使用
     */
    private String channelCode;

    public static PsMatchCampaignCond buildCond(Integer accessWay, Integer memberLevel, String channelCode) {
        PsMatchCampaignCond cond = new PsMatchCampaignCond();
        cond.setMatchCampaign(true);
        cond.setAccessWay(accessWay);
        cond.setMemberLevel(memberLevel);
        cond.setChannelCode(channelCode);
        return cond;
    }

    public Boolean getMatchGlobalCampaigns() {
        return matchGlobalCampaigns;
    }

    public List<Long> getCampaignIds() {
        return campaignIds;
    }

    public void setCampaignIds(List<Long> campaignIds) {
        this.campaignIds = campaignIds;
    }

    public List<Integer> getDiscountTypeIds() {
        return discountTypeIds;
    }

    public void setDiscountTypeIds(List<Integer> discountTypeIds) {
        this.discountTypeIds = discountTypeIds;
    }

    public List<Integer> getProductScopeIds() {
        return productScopeIds;
    }

    public void setProductScopeIds(List<Integer> productScopeIds) {
        this.productScopeIds = productScopeIds;
    }

    public List<Integer> getStates() {
        return states;
    }

    public void setStates(List<Integer> states) {
        this.states = states;
    }

    public void setMatchGlobalCampaigns(Boolean matchGlobalCampaigns) {
        this.matchGlobalCampaigns = matchGlobalCampaigns;
    }

    public Boolean getMatchCampaign() {
        return matchCampaign;
    }

    public void setMatchCampaign(Boolean matchCampaign) {
        this.matchCampaign = matchCampaign;
    }

    public Integer getMemberLevel() {
        return memberLevel;
    }

    public void setMemberLevel(Integer memberLevel) {
        this.memberLevel = memberLevel;
    }

    public Integer getAccessWay() {
        return accessWay;
    }

    public void setAccessWay(Integer accessWay) {
        this.accessWay = accessWay;
    }

    public BigDecimal getDiscount() {
        return discount;
    }

    public void setDiscount(BigDecimal discount) {
        this.discount = discount;
    }

    public BigDecimal getBdDiscount() {
        return bdDiscount;
    }

    public void setBdDiscount(BigDecimal bdDiscount) {
        this.bdDiscount = bdDiscount;
    }

    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }

    public List<String> getCampaignCodes() {
        return campaignCodes;
    }

    public void setCampaignCodes(List<String> campaignCodes) {
        this.campaignCodes = campaignCodes;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public List<Integer> getAccessWayIds() {
        return accessWayIds;
    }

    public void setAccessWayIds(List<Integer> accessWayIds) {
        this.accessWayIds = accessWayIds;
    }

    public List<Integer> getBuIds() {
        return buIds;
    }

    public void setBuIds(List<Integer> buIds) {
        this.buIds = buIds;
    }
}

==> pegasus-merchandise-api-3.4.4-sources.jar: com/thebeastshop/pegasus/merchandise/cond/PsMatchCampaignCond.java <==
package com.thebeastshop.pegasus.merchandise.cond;

import com.thebeastshop.common.BaseQueryCond;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * @author gongjun
 * @since 2016-07-18
 */
public class PsMatchCampaignCond extends BaseQueryCond {

    protected Boolean matchGlobalCampaigns = true;

    protected Boolean matchCampaign = true;

    private List<Long> campaignIds;

    private List<String> campaignCodes;

    List<Integer> discountTypeIds;

    List<Integer> productScopeIds;

    List<Integer> states;

    private Integer memberLevel;

    private Integer accessWay;

    private BigDecimal discount;

    private BigDecimal bdDiscount;

    private Date startTime;
    private Date endTime;
    private List<Integer> accessWayIds;
    private List<Integer> buIds;

    private Boolean matchFirstBuy = false;

    /**
     * 查询渠道编码，判断活动排除线下门店使用
     */
    private String channelCode;

    public static PsMatchCampaignCond buildCond(Integer accessWay, Integer memberLevel, String channelCode) {
        PsMatchCampaignCond cond = new PsMatchCampaignCond();
        cond.setMatchCampaign(true);
        cond.setAccessWay(accessWay);
        cond.setMemberLevel(memberLevel);
        cond.setChannelCode(channelCode);
        return cond;
    }

    public Boolean getMatchGlobalCampaigns() {
        return matchGlobalCampaigns;
    }

    public List<Long> getCampaignIds() {
        return campaignIds;
    }

    public void setCampaignIds(List<Long> campaignIds) {
        this.campaignIds = campaignIds;
    }

    public List<Integer> getDiscountTypeIds() {
        return discountTypeIds;
    }

    public void setDiscountTypeIds(List<Integer> discountTypeIds) {
        this.discountTypeIds = discountTypeIds;
    }

    public List<Integer> getProductScopeIds() {
        return productScopeIds;
    }

    public void setProductScopeIds(List<Integer> productScopeIds) {
        this.productScopeIds = productScopeIds;
    }

    public List<Integer> getStates() {
        return states;
    }

    public void setStates(List<Integer> states) {
        this.states = states;
    }

    public void setMatchGlobalCampaigns(Boolean matchGlobalCampaigns) {
        this.matchGlobalCampaigns = matchGlobalCampaigns;
    }

    public Boolean getMatchCampaign() {
        return matchCampaign;
    }

    public void setMatchCampaign(Boolean matchCampaign) {
        this.matchCampaign = matchCampaign;
    }

    public Integer getMemberLevel() {
        return memberLevel;
    }

    public void setMemberLevel(Integer memberLevel) {
        this.memberLevel = memberLevel;
    }

    public Integer getAccessWay() {
        return accessWay;
    }

    public void setAccessWay(Integer accessWay) {
        this.accessWay = accessWay;
    }

    public BigDecimal getDiscount() {
        return discount;
    }

    public void setDiscount(BigDecimal discount) {
        this.discount = discount;
    }

    public BigDecimal getBdDiscount() {
        return bdDiscount;
    }

    public void setBdDiscount(BigDecimal bdDiscount) {
        this.bdDiscount = bdDiscount;
    }

    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }

    public List<String> getCampaignCodes() {
        return campaignCodes;
    }

    public void setCampaignCodes(List<String> campaignCodes) {
        this.campaignCodes = campaignCodes;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public List<Integer> getAccessWayIds() {
        return accessWayIds;
    }

    public void setAccessWayIds(List<Integer> accessWayIds) {
        this.accessWayIds = accessWayIds;
    }

    public List<Integer> getBuIds() {
        return buIds;
    }

    public void setBuIds(List<Integer> buIds) {
        this.buIds = buIds;
    }

    public Boolean getMatchFirstBuy() {
        return matchFirstBuy;
    }

    public void setMatchFirstBuy(Boolean matchFirstBuy) {
        this.matchFirstBuy = matchFirstBuy;
    }
}
